# -*- coding: utf-8 -*-

from PyQt4.QtCore import *
from PyQt4.QtGui import QImage, QPainter, QCursor
from PyKDE4.plasma import Plasma
from PyKDE4.kdeui import KApplication, KWindowSystem
from PyKDE4 import plasmascript

HorizontalUp, VerticalRight, HorizontalDown, VerticalLeft = range(4)

class BChocobo(plasmascript.Applet):
    def __init__(self,parent,args=None):
        plasmascript.Applet.__init__(self,parent)

    def init(self):
        self.setAspectRatioMode(Plasma.KeepAspectRatio)

        self.setHasConfigurationInterface(False)
        self.setBackgroundHints(Plasma.Applet.NoBackground)

        self.orientation = HorizontalUp
        self.runState = 0
        self.runSvgChange = 0

        self.svgChocobo1 = Plasma.Svg(self)
        self.svgChocobo1.setImagePath(self.package().filePath("images", "chocobo_run1.svg"))
        self.svgChocobo2 = Plasma.Svg(self)
        self.svgChocobo2.setImagePath(self.package().filePath("images", "chocobo_run2.svg"))

        self.screenSize = self.screenSize()
        #print(self.screenSize)
        self.setMaximumSize(QSizeF(self.screenSize.width() / 20.0, self.screenSize.width() / 20.0 * self.aspectRatio()))
        self.resize(QSizeF(self.maximumWidth(), self.maximumHeight()))
        self.updateSvgSize(self.size())
        
        self.mousePressed = False

        self.timer = QTimer(self)
        self.connect(self.timer, SIGNAL ("timeout ()"), self.animation)
        self.timer.start(50)

    def screenSize(self):
        app = KApplication.kApplication()
        #print(app)
        if app.desktop().screenCount() > 1 or app.desktop().isVirtualDesktop():
            screenNum = KApplication.desktop().screenNumber(QCursor.pos()) #unreliable
            return KWindowSystem.workArea().intersect(app.desktop().screenGeometry(screenNum))
        else:
            return KWindowSystem.workArea()

    def aspectRatio(self):
        return (207.0/166.0)
 
    def paintInterface(self, painter, option, rect):
        if self.runState == 1:
            self.svgChocobo1.paint(painter, 0, 0)
        else:
            self.svgChocobo2.paint(painter, 0, 0)

    def updateSvgSize(self, size):
        self.svgChocobo1.resize(size)
        self.svgChocobo2.resize(size)

    def animation(self):
        if self.mousePressed:
            return
        
        if self.runSvgChange == 2:
            self.runSvgChange = 0
            if self.runState == 0:
                self.runState = 1
            else:
                self.runState = 0
            self.update()
        else:
            self.runSvgChange += 1

        #50/(1000/300) == 15
        pixDiff = 15

        newX = self.x()
        newY = self.y()

        if self.orientation == HorizontalUp:
            print("HorizontalUp")
            newX += pixDiff
            if newX > self.screenSize.x() + self.screenSize.width() - self.geometry().width():
                newX = self.screenSize.x() + self.screenSize.width() - self.geometry().height()
                self.rotate(-90)
                newY += self.geometry().width()
                self.orientation = VerticalRight
        elif self.orientation == VerticalRight:
            print("VerticalRight")
            newY -= pixDiff
            if newY < self.screenSize.y() + self.geometry().height():
                newY = self.screenSize.y() + self.geometry().height()
                self.rotate(-90)
                newX += self.geometry().height()
                self.orientation = HorizontalDown
        elif self.orientation == HorizontalDown:
            print("HorizontalDown")
            newX -= pixDiff
            if newX < self.screenSize.x() + self.geometry().width():
                newX = self.screenSize.x() + self.geometry().height()
                self.rotate(-90)
                newY -= self.geometry().width()
                self.orientation = VerticalLeft
        elif self.orientation == VerticalLeft:
            print("VerticalLeft")
            newY += pixDiff
            if newY > self.screenSize.y() + self.screenSize.height() - self.geometry().height():
                newY = self.screenSize.y() + self.screenSize.height() - self.geometry().height()
                self.rotate(-90)
                newX -= self.geometry().width()
                self.orientation = HorizontalUp

        self.setPos(newX, newY)


    def constraintsEvent(self, constraints):
        if constraints & Plasma.FormFactorConstraint:
            self.setBackgroundHints(Plasma.Applet.NoBackground)

        if constraints & Plasma.SizeConstraint:
            self.updateSvgSize(self.size())

    def mouseReleaseEvent(self, event):
        print("release")
        self.mousePressed = False;
        event.accept()

    def mousePressEvent(self, event):
        print("press")
        self.mousePressed = True;
        event.accept()



def CreateApplet(parent):
    return BChocobo(parent)

